@@ -1,11 +1,11 @@
 /*
-  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2020 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
-  You may not use this file except in compliance with the License.
+  You may not use this file except in compliance with the License.  You may
   obtain a copy of the License at
   
-    http://www.imagemagick.org/script/license.php
+    https://imagemagick.org/script/license.php
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -15,8 +15,8 @@
 
   MagickCore methods to lock and unlock semaphores.
 */
-#ifndef _MAGICKCORE_SEMAPHORE_H
-#define _MAGICKCORE_SEMAPHORE_H
+#ifndef MAGICKCORE_SEMAPHORE_H
+#define MAGICKCORE_SEMAPHORE_H
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
@@ -25,19 +25,21 @@ extern "C" {
 typedef struct SemaphoreInfo
   SemaphoreInfo;
 
+extern MagickExport void
+  SemaphoreComponentTerminus(void);
+
 extern MagickExport MagickBooleanType
-  LockSemaphoreInfo(SemaphoreInfo *),
-  UnlockSemaphoreInfo(SemaphoreInfo *);
+  SemaphoreComponentGenesis(void);
 
 extern MagickExport SemaphoreInfo
   *AllocateSemaphoreInfo(void);
 
 extern MagickExport void
-  AcquireSemaphoreInfo(SemaphoreInfo **),
-  DestroySemaphore(void),
+  ActivateSemaphoreInfo(SemaphoreInfo **),
   DestroySemaphoreInfo(SemaphoreInfo **),
-  InitializeSemaphore(void),
-  RelinquishSemaphoreInfo(SemaphoreInfo *);
+  LockSemaphoreInfo(SemaphoreInfo *),
+  SemaphoreComponentTerminus(void),
+  UnlockSemaphoreInfo(SemaphoreInfo *);
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
